import json
import asyncio
from pyscoresaber import ScoreSaberAPI, ScoreSort

blee_id = '76561199407393962'
isuldor_id = '76561197962107242'

async def show_player(player_id):
    async with ScoreSaberAPI() as scoresaber:
        return await scoresaber.player_full(player_id)

async def get_all_player_scores(scoresaber: ScoreSaberAPI, player_id: int, score_sort: ScoreSort):
    all_scores = []
    async for player_scores in scoresaber.player_scores_all(player_id, score_sort):
        all_scores.extend(player_scores)
    return all_scores

def filter_and_sort_scores_by_stars(scores, min_stars=0.1, max_stars=float('inf')):
    # Exclude scores outside the specified star range
    filtered_scores = [score for score in scores if min_stars <= score.leaderboard.stars < max_stars]
    # Sort the remaining scores by stars
    sorted_scores = sorted(filtered_scores, key=lambda x: x.leaderboard.stars)
    return sorted_scores

def scores_to_playlist(scores, playlist_title, playlist_author, filename):
    playlist = {
        "playlistTitle": playlist_title,
        "playlistAuthor": playlist_author,
        "songs": []
    }

    for score in scores:
        song_entry = {
            "hash": score.leaderboard.song_hash,
            "songName": score.leaderboard.song_name,
            "difficulties": [
                {
                    "name": score.leaderboard.difficulty.difficulty.name.lower(),
                    "characteristic": score.leaderboard.difficulty.game_mode.value
                }
            ],
            "levelAuthorName": score.leaderboard.level_author_name
        }
        playlist["songs"].append(song_entry)
    
    playlist_json = json.dumps(playlist)

    with open(filename, 'w') as file:
        file.write(playlist_json)

def scores_to_playlist(scores, playlist_title, playlist_author, filename):
    playlist = {
        "playlistTitle": playlist_title,
        "playlistAuthor": playlist_author,
        "songs": []
    }

    for score in scores:
        song_entry = {
            "hash": score.leaderboard.song_hash,
            "songName": score.leaderboard.song_name,
            "difficulties": [
                {
                    "name": score.leaderboard.difficulty.difficulty.name.lower(),
                    "characteristic": score.leaderboard.difficulty.game_mode.name.lower()
                }
            ],
            "levelAuthorName": score.leaderboard.level_author_name
        }
        playlist["songs"].append(song_entry)
    

    playlist_json = json.dumps(playlist, indent=4)
    with open(filename, 'w') as file:
        file.write(playlist_json)

    return playlist_json

async def build_playlists(player_id):
    async with ScoreSaberAPI() as api:
        scores = await get_all_player_scores(api, player_id, ScoreSort.TOP)
        return scores

    scores = asyncio.run(build_playlists(blee_id))

    filtered_sorted_scores = filter_and_sort_scores_by_stars(scores, min_stars=2, max_stars=3)
    scores_to_playlist(filtered_sorted_scores, "Played SS TWO\u2605", "ScoreSaber", "Played SS TWO.bplist")
    filtered_sorted_scores = filter_and_sort_scores_by_stars(scores, min_stars=3, max_stars=4)
    scores_to_playlist(filtered_sorted_scores, "Played SS THREE\u2605", "ScoreSaber", "Played SS THREE.bplist")
    filtered_sorted_scores = filter_and_sort_scores_by_stars(scores, min_stars=4, max_stars=5)
    scores_to_playlist(filtered_sorted_scores, "Played SS FOUR\u2605", "ScoreSaber", "Played SS FOUR.bplist")
